summaryrefslogtreecommitdiff
path: root/compiler/GHC/CoreToStg.hs
diff options
context:
space:
mode:
authorSylvain Henry <sylvain@haskus.fr>2020-03-02 11:43:03 +0100
committerMarge Bot <ben+marge-bot@smart-cactus.org>2020-03-16 23:53:24 -0400
commit18a346a4b5a02b8c62e8eedb91b35c2d8e754b96 (patch)
tree59121ffd5a46c1987a184db3842a3089f6250d11 /compiler/GHC/CoreToStg.hs
parent818b3c38e7548f4720815f76969238d82c9650f7 (diff)
downloadhaskell-18a346a4b5a02b8c62e8eedb91b35c2d8e754b96.tar.gz
Modules: Core (#13009)
Update submodule: haddock
Diffstat (limited to 'compiler/GHC/CoreToStg.hs')
-rw-r--r--compiler/GHC/CoreToStg.hs8
1 files changed, 4 insertions, 4 deletions
diff --git a/compiler/GHC/CoreToStg.hs b/compiler/GHC/CoreToStg.hs
index 55771b30a9..786792ea0f 100644
--- a/compiler/GHC/CoreToStg.hs
+++ b/compiler/GHC/CoreToStg.hs
@@ -23,13 +23,13 @@ import GHC.Core.Utils ( exprType, findDefault, isJoinBind
import GHC.Core.Arity ( manifestArity )
import GHC.Stg.Syntax
-import Type
+import GHC.Core.Type
import GHC.Types.RepType
-import TyCon
+import GHC.Core.TyCon
import MkId ( coercionTokenId )
import Id
import IdInfo
-import DataCon
+import GHC.Core.DataCon
import CostCentre
import VarEnv
import Module
@@ -449,7 +449,7 @@ coreToStgExpr e0@(Case scrut bndr _ alts) = do
vars_alt (con, binders, rhs)
| DataAlt c <- con, c == unboxedUnitDataCon
= -- This case is a bit smelly.
- -- See Note [Nullary unboxed tuple] in Type.hs
+ -- See Note [Nullary unboxed tuple] in GHC.Core.Type
-- where a nullary tuple is mapped to (State# World#)
ASSERT( null binders )
do { rhs2 <- coreToStgExpr rhs